RxController class abstract

Base controller like GetxController but uses rxdart

Constructors

RxController()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addWorker(StreamSubscription sub) → void
Register a subscription for auto-dispose
bindState<T>(RxState<T> stateVar, Stream<T> source) → void
debounce<T>(RxVar<T> rx, void worker(T), {Duration duration = const Duration(milliseconds: 500)}) → void
dispose() → void
Dispose workers & streams
ever<T>(RxVar<T> rx, void worker(T?)) → void
Worker helpers (auto-dispose)
everAll(List<RxVar> list, void worker(List values)) → void
interval<T>(RxVar<T> rx, void worker(T), {Duration duration = const Duration(milliseconds: 500), bool leading = true}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onClose() → void
Called before controller is destroyed
onInit() → void
Called when controller is allocated
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited