RxStateBase<T> class abstract

Implementers

Constructors

RxStateBase()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<R>({required R idle(), required R loading(), required R onData(T data), required R onError(Failure failure)}) → R

Operators

operator ==(Object other) bool
The equality operator.
inherited