RxVar<T> class

Constructors

RxVar([T? initial])

Properties

hashCode int
The hash code for this object.
no setterinherited
hasValue bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<T>
Stream for listening
no setter
value ↔ T
Current value
getter/setter pair

Methods

dispose() → void
Close the stream
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited